#!/usr/bin/env python
#------------------------------------------------------------#
# Author:    Yasuko Matsubara 
# Email:     yasuko@cs.kumamoto-u.ac.jp
# URL:       http://www.cs.kumamoto-u.ac.jp/~yasuko/
# Date:      2016-09-15
#------------------------------------------------------------#
# Copyright (C) 2015--2016 Yasuko Matsubara & Yasushi Sakurai
# RegimeCast is freely available for non-commercial purposes
#------------------------------------------------------------#

import tool as tl
import numpy as np
import argparse
import sys
import regimecast 

#------------------------#
#     main function   
#     e.g., python main_fit.py [-h] [-s SEQFN] [-o OUTDIR] [-d on/off]
#------------------------#
if __name__ == "__main__":
    #--- arguments ---#
    parser = argparse.ArgumentParser()
    #-----------------------------------#
    parser.add_argument("-s",  "--seqfn", type=str, help="input seqs filename")
    parser.add_argument("-l",  "--lstep", type=int, help="l-step-ahead")
    parser.add_argument("-o",  "--outdir",type=str, help="output dir")
    #-----------------------------------#
    parser.add_argument("-q",  "--MDBfn", type=str, help="input modelDB filename (optional)")
    parser.add_argument("-i",  "--insert",type=str, help="insert/update MDB (optional)")
    parser.add_argument("-n",  "--n",     type=int, help="duration (optional)")
    parser.add_argument("-p",  "--dps", type=float, help="DPS-rate (default:0.1)")
    #-----------------------------------#
    args = parser.parse_args()
    if(len(sys.argv)<2):
        parser.print_help()
    #-----------------------------------#
    #--- check sequencefn ---#
    if(args.seqfn!=None):
        seqfn = args.seqfn
    else: parser.print_help()
    #--- check l-step-ahead ---#
    if(args.lstep!=None):
        lstep = args.lstep
    else: parser.print_help()
    #--- check output dir ---#
    if(args.outdir!=None): 
        outdir = args.outdir
    else: parser.print_help()
    #-----------------------------------#
    #--- check insert ---#
    if(args.insert=='no'): insert=tl.NO;
    else: insert = tl.YES;
    #--- check modelfn ---#
    if(args.MDBfn!=None):
        MDBfn = args.MDBfn
    else: MDBfn = ''
        #--- check n (duration) ---#
    if(args.n!=None): my_n=args.n
    else: my_n=tl.INF
    #--- check dps  ---#
    if(args.dps!=None): my_dps_r=args.dps
    else: my_dps_r=0.1
    #-----------------------------------#
    tl.comment("RegimeCast")
    #-----------------------------------#
    tl.comment('args/data/info')
    tl.msg("seqfn: [%s]"%seqfn)
    tl.msg("l-step-ahead: [%d]"%lstep)
    tl.msg("outdir:[%s]"%outdir)
    tl.msg("duration: [%s]"%my_n)
    tl.msg("queryfn (if any): [%s]"%MDBfn)
    tl.msg("update MDB: [%r] (1:yes,0:no)"%insert)
    tl.msg("dps_r: [%.1f]"%my_dps_r)
    tl.msg("dps: [%d]"%max(1,lstep*my_dps_r))
    #-----------------------------------#
    # create directory
    try:
        tl.mkdir("%s_mdb"%outdir)
    except:
        tl.error("cannot find: %s"%outdir)
    # load data (event stream)
    data=tl.loadsq(seqfn).T
    (n,d) = np.shape(data)
    # avoid zero/nan (kf) 
    data+=0.001*np.random.rand(n,d)
    #--- set data length (my_n) ---#
    if(my_n < n): 
        data=data[0:my_n,:]
        (n,d) = np.shape(data)
    data=tl.normalizeZ(data)
    tl.save_txt(data, '%sX'%(outdir))
    #--- load modelDB (if any) ---#
    MDBH=[];
    if(MDBfn!=''):
        try: MDBH=tl.load_obj("%s"%(MDBfn))
        except: tl.warning("cannot find: %s"%(MDBfn)); MQHs=[]
    
    #-----------------------------------#
    # start regimecast 
    #-----------------------------------#
    regimecast.run(data, lstep, MDBH, outdir, my_dps_r, insert)
    #-----------------------------------#

    sys.exit(0);



