%------------------------------------------------------------
% Author:    Yasuko Matsubara 
% Email:     yasuko@cs.kumamoto-u.ac.jp
% URL:       http://www.cs.kumamoto-u.ac.jp/~yasuko/
% Date:      2016-09-15
%------------------------------------------------------------
% Copyright (C) 2015--2016 Yasuko Matsubara & Yasushi Sakurai
%------------------------------------------------------------
function [n, X, Vf_full] = M_regimesnap_full(DIR, OUTDIR)
%-------------------------%
grcol=[.6 .6 .6];
%-------------------------%
if(~strcmp(OUTDIR,''))
    fDIR=OUTDIR; 
else
    fDIR='./_tmp/';
end;
%-------------------------%

% setting 
fig1=true;
fig2=false;
fig3=true;
fig4=true;

%-------------------------%
% load data
%-------------------------%
X=load([DIR,'X']);              % original event stream X
[n,d]=size(X);
Vf_full=load([DIR,'Vf_full']);  % forecasted events
Errs=load([DIR,'ERR_full']);    % errors
TIMEs=load([DIR,'TIME_full']);  % time 
mx=max(X(:)); mn=min(X(:));     % min,max
tick_st=find_start(Vf_full);    % starting position 
%-------------------------%
XH=[]; VfH=[]; RSH={};
i=1;
%-------------------------%
while(1)
    try
        XH(:,:,i)=load([DIR,['XH_',num2str(i-1)]]);
        VfH(:,:,i)=load([DIR,'VfH_',num2str(i-1)]);
        RSH{i}=load([DIR,'RSH_',num2str(i-1)]);
        i=i+1;
    catch
        HEIGHT=i-1;
        break;
    end
end
%-------------------------%



%-------------------------%
% plot results
%-------------------------%

if(fig1)
%---------------%
figure(1)
%---------------%
subplot(211)
plot(X); %hold on;
ylim([mn,mx]); xlim([1,n])
title('Original data'); largefont_s(12);
ylabel('Value')
xlabel('Time')
%---------------%
subplot(212)
plot(Vf_full); ylim([mn,mx]); xlim([1,n])
 M_plotLines([tick_st], mn, mx, 'black')
largefont_s(12);
title('Forecasted result'); 
ylabel('Value')
xlabel('Time')
%---------------%
saveas(gcf,[fDIR,'fig1.png'])
saveas(gcf,[fDIR,'fig1.fig'])
%---------------%
end

if(fig2)
%---------------%
figure(2); 
%---------------%
for i=1:HEIGHT %height
    mymn=min(min(XH(:,:,i)));
    mymx=max(max(XH(:,:,i)));
	subplot(HEIGHT,1,i)
    plot(XH(:,:,i), '-', 'LineWidth', 1, 'color',grcol)
    hold on
    %plot(VeH(:,:,i), '-', 'color',[.9,.6,.6])
    plot(VfH(:,:,i))
    hold off;
	%M_plotLines([tick_st], mn, mx, 'black')
    title(['Level ',num2str(i)])
    ylim([mymn,mymx]);xlim([1,n])
end
%---------------%
saveas(gcf,[fDIR,'fig2.png'])
saveas(gcf,[fDIR,'fig2.fig'])
%---------------%
end

if(fig3)
%---------------%
figure(3)
%---------------%
subplot(211)
plot(M_error_each(X,X*0,1), 'g');
hold on;
plot(Errs(:,1), 'r'); % error(Xc-Vc)
%plot(Errs(:,2), 'm'); % error(Xf-Vf)
plot(M_error_each(X, Vf_full,1), 'b'); % error(xf-Vf_full)
[n,d]=size(X);
hold off;
legend('rmse(Xc)', 'rmse(Xc-Ve)', 'rmse(Xc-Vf)')
xlim([tick_st,n])
title('Error'); xlabel('Time');
subplot(212)
semilogy(TIMEs(:,1), 'x:'); 
xlim([tick_st,n]); 
title('Speed'); xlabel('Time');
legend('RegimeCast')
%---------------%
saveas(gcf,[fDIR,'fig3.png'])
saveas(gcf,[fDIR,'fig3.fig'])
%---------------%
end

if(fig4)
%---------------%
figure(4); 
%---------------%
for i=1:HEIGHT %height
	subplot(HEIGHT,1,i)
    imagesc(RSH{i}')
    xlabel('Time'); ylabel('Regimes'); 
    title(['Level ',num2str(i)])
end
%---------------%
saveas(gcf,[fDIR,'fig4.png'])
saveas(gcf,[fDIR,'fig4.fig'])
%---------------%
end

%---------------%
gfigure 450 400;
%---------------%

end

% find starting position
function [st] = find_start(X)
n=length(X(:,1));
st=1;
for i=1:n
    if(isnan(X(i,1)))
        st=i;
    else
        break
    end
end
end
